Module executor_process

Module executor_process 

kapot Executor Process

Structs

ExecutorProcessConfig

Functions

satisfy_dir_ttl
Determines if a directory contains files newer than the cutoff time. If return true, it means the directory contains files newer than the cutoff time. It satisfy the ttl and should not be deleted.
start_executor_process