Function satisfy_dir_ttl

pub async fn satisfy_dir_ttl(dir: DirEntry, ttl_seconds: u64) -> Result<bool>
Determines if a directory contains files newer than the cutoff time. If return true, it means the directory contains files newer than the cutoff time. It satisfy the ttl and should not be deleted.