pub struct ExecutorServer<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> { /* private fields */ }Trait Implementations
Sourceimpl<T: Clone + 'static + AsLogicalPlan, U: Clone + 'static + AsExecutionPlan> Clone for ExecutorServer<T, U>
impl<T: Clone + 'static + AsLogicalPlan, U: Clone + 'static + AsExecutionPlan> Clone for ExecutorServer<T, U>
Sourcefn clone(&self) -> ExecutorServer<T, U>
fn clone(&self) -> ExecutorServer<T, U>
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> ExecutorGrpc for ExecutorServer<T, U>
impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> ExecutorGrpc for ExecutorServer<T, U>
Sourcefn launch_multi_task<'life0, 'async_trait>(
&'life0 self,
request: Request<LaunchMultiTaskParams>,
) -> Pin<Box<dyn Future<Output = Result<Response<LaunchMultiTaskResult>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn launch_multi_task<'life0, 'async_trait>(
&'life0 self,
request: Request<LaunchMultiTaskParams>,
) -> Pin<Box<dyn Future<Output = Result<Response<LaunchMultiTaskResult>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
by this interface, it can reduce the deserialization cost for multiple tasks belong to the same job stage running on the same one executor
fn launch_task<'life0, 'async_trait>(
&'life0 self,
request: Request<LaunchTaskParams>,
) -> Pin<Box<dyn Future<Output = Result<Response<LaunchTaskResult>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn stop_executor<'life0, 'async_trait>(
&'life0 self,
request: Request<StopExecutorParams>,
) -> Pin<Box<dyn Future<Output = Result<Response<StopExecutorResult>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn cancel_tasks<'life0, 'async_trait>(
&'life0 self,
request: Request<CancelTasksParams>,
) -> Pin<Box<dyn Future<Output = Result<Response<CancelTasksResult>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn remove_job_data<'life0, 'async_trait>(
&'life0 self,
request: Request<RemoveJobDataParams>,
) -> Pin<Box<dyn Future<Output = Result<Response<RemoveJobDataResult>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,