pub struct ShutdownNotifier {
pub notify_shutdown: Sender<()>,
pub shutdown_complete_rx: Receiver<()>,
pub shutdown_complete_tx: Sender<()>,
}Fields
notify_shutdown: Sender<()>Broadcasts a shutdown signal to all related components.
shutdown_complete_rx: Receiver<()>Used as part of the graceful shutdown process to wait for related components to complete processing.
Tokio channels are closed once all Sender handles go out of scope.
When a channel is closed, the receiver receives None. This is
leveraged to detect all shutdown processing completing.
shutdown_complete_tx: Sender<()>Implementations
Sourceimpl ShutdownNotifier
impl ShutdownNotifier
Sourcepub fn subscribe_for_shutdown(&self) -> Shutdown
pub fn subscribe_for_shutdown(&self) -> Shutdown
Subscribe for shutdown notification