kapot Executor Process
Structs
Functions
- satisfy_
dir_ ttl - Determines if a directory contains files newer than the cutoff time. If return true, it means the directory contains files newer than the cutoff time. It satisfy the ttl and should not be deleted.
- start_
executor_ process